'use strict';

exports.__esModule = true;
exports.default = devTools;

var _jsan = require('jsan');

var _socketclusterClient = require('socketcluster-client');

var _socketclusterClient2 = _interopRequireDefault(_socketclusterClient);

var _configureStore = require('./configureStore');

var _configureStore2 = _interopRequireDefault(_configureStore);

var _constants = require('./constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var instanceName = undefined;
var socket = undefined;
var channel = undefined;
var store = {};
var shouldInit = true;
var actionsCount = 0;
var reducedState = undefined;

function relay(type, state, action, nextActionId) {
  setTimeout(function () {
    var message = {
      payload: state ? (0, _jsan.stringify)(state) : '',
      action: action ? (0, _jsan.stringify)(action) : '',
      nextActionId: nextActionId || '',
      type: type,
      id: socket.id,
      name: instanceName,
      init: shouldInit
    };
    if (shouldInit) shouldInit = false;

    socket.emit(socket.id ? 'log' : 'log-noid', message);
  }, 0);
}

function handleMessages(message) {
  if (message.type === 'DISPATCH') {
    store.liftedStore.dispatch(message.action);
  } else if (message.type === 'UPDATE') {
    relay('STATE', store.liftedStore.getState());
  } else if (message.type === 'SYNC') {
    if (socket.id && message.id !== socket.id) {
      store.liftedStore.dispatch({
        type: 'IMPORT_STATE', nextLiftedState: (0, _jsan.parse)(message.state)
      });
    }
  }
}

function init(options) {
  if (channel) channel.unwatch();
  if (socket) socket.disconnect();
  socket = _socketclusterClient2.default.connect(options && options.port ? options : _constants.socketOptions);

  socket.emit('login', 'master', function (err, channelName) {
    if (err) {
      console.error(err);return;
    }
    channel = socket.subscribe(channelName);
    channel.watch(handleMessages);
    socket.on(channelName, handleMessages);
  });

  if (options) instanceName = options.name;
}

function subscriber() {
  var state = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
  var action = arguments[1];

  if (action && action.type) {
    if (action.type === '@@redux/INIT') {
      actionsCount = 1;
      relay('INIT', reducedState, { timestamp: Date.now() });
    } else if (action.type === 'PERFORM_ACTION') {
      actionsCount++;
      relay('ACTION', reducedState, action, actionsCount);
    } else {
      setTimeout(function () {
        var liftedState = store.liftedStore.getState();
        relay('STATE', liftedState);
      }, 0);
    }
  }
  return state;
}

function createReducer(reducer) {
  return function (state, action) {
    reducedState = reducer(state, action);
    return reducedState;
  };
}

function devTools(options) {
  return function (next) {
    return function (reducer, initialState) {
      init(options);
      store = (0, _configureStore2.default)(next, subscriber)(createReducer(reducer), initialState);
      return store;
    };
  };
}